@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10341 2017-10-03 08:42:24Z Lavender $
+# $Id: build_templates.py 10389 2017-10-22 05:43:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-03 16:42:24 +0800 (週二, 03 十月 2017) $
-# $Revision: 10341 $
+# $Date: 2017-10-22 13:43:34 +0800 (週日, 22 十月 2017) $
+# $Revision: 10389 $
 
 import os
 import sys
 import shutil
 
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 from django.conf import settings
 
 from Zephyrus.boilerplate.management.commands import (
@@ -60,7 +60,7 @@ class Command(BaseCommand):
 
             # get_template
             error = os.system(
-                "%s manage.py get_template %s" % (sys.executable,  tempPath))
+                "%s manage.py get_template %s" % (sys.executable, tempPath))
             if not error == 0:
                 logger.error(
                     "get_template error code: %d, from template: %s" % 
@@ -69,7 +69,7 @@ class Command(BaseCommand):
 
             # build_boilerplate
             error = os.system(
-                "%s manage.py build_boilerplate %s" % 
+                "%s manage.py build_boilerplate2 %s" % 
                 (sys.executable, TEMPLATES_DIR_PATH))
             if not error == 0:
                 logger.error(
@@ -127,4 +127,5 @@ class Command(BaseCommand):
                 logger.error(
                     "create_zip error code: %d, from template: %s" % 
                     (error, tempPath))
-                continue
\ No newline at end of file
+                continue
+            
\ No newline at end of file
