@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_pages.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: create_pages.py 10372 2017-10-15 06:37:53Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-10-15 14:37:53 +0800 (週日, 15 十月 2017) $
+# $Revision: 10372 $
 
 import os
 import json
@@ -42,6 +42,8 @@ class Command(BaseCommand):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
                 data = json.load(jsonfile)
                 slug = data['slug']
+        else:
+            slug = None
 
         for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
 
