@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10307 2017-09-19 11:46:01Z Lavender $
+# $Id: pluginize.py 10439 2017-11-05 09:05:24Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-19 19:46:01 +0800 (週二, 19 九月 2017) $
-# $Revision: 10307 $
+# $Date: 2017-11-05 17:05:24 +0800 (週日, 05 十一月 2017) $
+# $Revision: 10439 $
 
 import os
 import json
@@ -45,21 +45,22 @@ jsPath = os.path.join(STATIC_DIR_PATH, 'js', 'FixTemplate.js')
 
 complexity = 0
 
-imgList = []
+tagList = []
 
 class Attr(object):
     def __init__(self, name, value):
         self.name = name
         self.value = value 
 
-class Img(object):
-    def __init__(self, name, md5, attrList):
-        self.name = name
+class Tag(object):
+    def __init__(self, tagName, placeholderName, md5, attrList):
+        self.tag = tagName
+        self.name = placeholderName
         self.md5 = md5
         self.attrList = attrList
 
     def __eq__(self, other):
-        if self.name == other.name:
+        if self.name == other.name and self.tag == other.tag:
             return True
         return False
 
@@ -102,7 +103,7 @@ class Placeholder2(Placeholder):
                 f.write(line)
         
         for placeholder in placeholders:
-            logger.info("id: %s, name: %s" % (placeholder.id, placeholder.slot))
+            # logger.info("id: %s, name: %s" % (placeholder.id, placeholder.slot))
             hasTextPlugin = Text.objects.filter(
                                     placeholder=placeholder, position=0
                             ).exists()
@@ -111,41 +112,85 @@ class Placeholder2(Placeholder):
 
             if not hasTextPlugin and not hasImgPlugin:
                 string = content.lower().strip()
+                
+                isOutSideTag = False
+                if string.startswith('<') and string.endswith('>'):
+                    isOutSideTag = True
 
-                isTagOnly = False
+                isImgTag = False
                 if '>' in string:
-                    index = content.lower().strip().index('>')
+                    index = string.index('>')
                     if index == len(string) - 1:
-                        isTagOnly = True
+                        isImgTag = True
+                        
+                isImgA = False
+                if isOutSideTag and string.startswith('<a'):
+                    root = fromstring(content)
+                    children = root.getchildren()
+                    if len(children) == 1:
+                       if children[0].tag == 'img':
+                           isImgA = True
                      
-                if string.startswith('<img') and isTagOnly:
-                    img = fromstring(content)
+                if (string.startswith('<img') and isImgTag) or isImgA:
                     
+                    root = fromstring(content)
+                    
+                    if isImgA:
+                        img = root.getchildren()[0]
+                        # add a attrs
+                        attrList = []
+                        attrs = root.items()
+                        for k, v in attrs:
+                            if k == 'href':
+                                continue
+                            attrList.append(Attr(k, v))
+                        
+                        
+                        tagList.append(
+                            Tag('a', placeholder.slot, 
+                            hashlib.md5(
+                                placeholder.slot).hexdigest(), attrList))
+                    else:
+                        img = root
+                    
+                    
+                    # find img src
                     url = img.get('src')
                     if url is None:
                         continue
 
-                    attrs = img.items()
-
                     if url.startswith("{% static \"") and url.endswith("\" %}"):
                         url = "/static/" + url[12:-4]
 
+                    # add img attrs
                     attrList = []
+                    attrs = img.items()
                     for k, v in attrs:
                         if k == 'src':
                             continue
                         attrList.append(Attr(k, v))
                     
                     
-                    imgList.append(
-                        Img(placeholder.slot, 
+                    tagList.append(
+                        Tag('img', placeholder.slot, 
                         hashlib.md5(placeholder.slot).hexdigest(), attrList))
                     
                     
-                    FilerImage.objects.create(placeholder=placeholder,
-                                              language=Placeholder2.lang,
-                                              caption_text='', image_url=url,
-                                              plugin_type='FilerImagePlugin',)
+                    if root.tag == 'a':
+                        link = root.get('href')
+                        FilerImage.objects.create(
+                            placeholder=placeholder,
+                            language=Placeholder2.lang,
+                            caption_text='', image_url=url,
+                            plugin_type='FilerImagePlugin',
+                            free_link=link)
+
+                    else:
+                        FilerImage.objects.create(
+                            placeholder=placeholder,
+                            language=Placeholder2.lang,
+                            caption_text='', image_url=url,
+                            plugin_type='FilerImagePlugin',)
                     
                 else:
                 
@@ -225,6 +270,7 @@ class Command(BaseCommand):
                 c['request'].user = AnonymousUser()
                 c['request'].current_page = Page.objects.get(pk=1)
                 t.render(c)
+                f.close()
 
         process()
         """
@@ -234,14 +280,19 @@ class Command(BaseCommand):
             f.write("});")
         """
         # Unique List obj
-        newImgList = []
-        for img in imgList:
-            if not img in newImgList:
-                newImgList.append(img)
+        newTagList = []
+        for tag in tagList:
+            notAdd = False
+            for tag2 in newTagList:
+                if tag2 == tag:
+                    notAdd = True
+            if not notAdd:
+                newTagList.append(tag)
         temp = get_template('boilerplate/js/FixTemplate.js')
         replaceStr = Context({
-            'imgList': newImgList, 
+            'tagList': newTagList, 
         })
+        
         content = temp.render(replaceStr)
         with open(jsPath, 'w') as f:
             f.write(content)
